@@ -9,6 +9,20 @@ namespace NuGet.Test
 {
     public class VersionUtilityTest
     {
+        [Fact]
+        public void ParseUAPFrameworkShortName()
+        {
+            var shortName = VersionUtility.GetShortFrameworkName(new FrameworkName("UAP, Version=v10.0.10030"));
+            Assert.Equal("UAP10.0.10030", shortName);
+        }
+
+        [Fact]
+        public void ParseUAPFrameworkName()
+        {
+            var name = VersionUtility.ParseFrameworkName("uap10.0.10030");
+            Assert.Equal("UAP,Version=v10.0.10030", name.ToString());
+        }
+
         [Theory]
         [InlineData("boo\\foo.dll", "foo.dll")]
         [InlineData("far\\sub\\sub2\\foo.dll", "sub\\sub2\\foo.dll")]
@@ -1357,6 +1371,23 @@ namespace NuGet.Test
             Assert.Equal("sl", shortName);
         }
 
+        [Theory]
+        [InlineData("netcore45", "win")]
+        [InlineData("netcore451", "win81")]
+        [InlineData("netcore50", ".NETCore50")]
+        [InlineData("netcore53", ".NETCore53")]
+        public void GetShortNameForNetCoreFrameworks(string frameworkName, string expected)
+        {
+            // Arrange
+            FrameworkName framework = VersionUtility.ParseFrameworkName(frameworkName);
+
+            // Act
+            string actual = VersionUtility.GetShortFrameworkName(framework);
+
+            // Assert
+            Assert.Equal(expected, actual);
+        }
+
         [Theory]
         [InlineData("ASP.Net, Version=5.0", "aspnet50")]
         [InlineData("ASP.NetCore, Version=5.0", "aspnetcore50")]
@@ -1500,6 +1531,24 @@ namespace NuGet.Test
             Assert.True(isCompatible);
         }
 
+        [Theory]
+        [InlineData("netcore45", "win")]
+        [InlineData("netcore451", "win81")]
+        [InlineData("win", "netcore45")]
+        [InlineData("win81", "netcore451")]
+        public void IsCompatibleReturnsTrueForNetCoreAndWinFrameworks(string packageFramework, string projectFramework)
+        {
+            // Arrange
+            var packagePortableFramework = VersionUtility.ParseFrameworkName(packageFramework);
+            var projectPortableFramework = VersionUtility.ParseFrameworkName(projectFramework);
+
+            // Act
+            bool isCompatible = VersionUtility.IsCompatible(projectPortableFramework, packagePortableFramework);
+
+            // Assert
+            Assert.True(isCompatible);
+        }
+
         [Fact]
         public void IsCompatibleReturnsFalseForPortableFrameworkAndNormalFramework()
         {
@@ -1926,5 +1975,45 @@ namespace NuGet.Test
 
             return profileCollection;
         }
+
+        [Theory]
+        [InlineData("dotnet", ".NETPlatform", "5.0")]
+        [InlineData("dotnet10", ".NETPlatform", "1.0")]
+        [InlineData("dotnet50", ".NETPlatform", "5.0")]
+        [InlineData("dotnet60", ".NETPlatform", "6.0")]
+        public void CanParseShortFrameworkNames(string shortName, string longName, string version)
+        {
+            var fx = VersionUtility.ParseFrameworkName(shortName);
+            Assert.Equal(new FrameworkName(longName, Version.Parse(version)), fx);
+        }
+
+        [Theory]
+        [InlineData(".NETPlatform", "0.0", "dotnet")]
+        [InlineData(".NETPlatform", "5.0", "dotnet")]
+        public void ShortFrameworkNamesAreCorrect(string longName, string version, string shortName)
+        {
+            var fx = new FrameworkName(longName, Version.Parse(version));
+            Assert.Equal(shortName, VersionUtility.GetShortFrameworkName(fx));
+        }
+
+        [Theory]
+        [InlineData(".NETPlatform5.0", ".NETPlatform", "5.0")]
+        [InlineData(".NETPlatform50", ".NETPlatform", "5.0")]
+        public void CanParseMixedFrameworkNames(string mixedName, string longName, string version)
+        {
+            var fx = VersionUtility.ParseFrameworkName(mixedName);
+            Assert.Equal(new FrameworkName(longName, Version.Parse(version)), fx);
+        }
+
+        [Theory]
+        [InlineData(".NETPlatform5.0", "dotnet")]
+        [InlineData(".NETPlatform50", "dotnet")]
+        public void CanParseMixedFrameworkNamesToShort(string mixedName, string shortName)
+        {
+            var fx = VersionUtility.ParseFrameworkName(mixedName);
+            var result = VersionUtility.GetShortFrameworkName(fx);
+
+            Assert.Equal(shortName, result);
+        }
     }
 }
